package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: Jul 13, 2025
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Color struct {
TimFunc []colFunc
UptFunc []colFunc
LvlFunc []colFunc
SrcFunc []colFunc
MsgFunc []colFunc
KeyFunc []colFunc
ValFunc []colFunc
ErKFunc []colFunc
ErVFunc []colFunc
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.